@@ -7,9 +7,9 @@
 #'    H0 : f_1 = ... = f_K  against  H1 : f_i differs from f_j (i different from j, and i,j in 1,...,K).
 #'
 #' @param samples A list of the K samples to be studied, all following admixture distributions.
-#' @param admixMod A list of objects of class class \link[admix]{admix_model}, containing useful information about distributions and parameters.
+#' @param admixMod A list of objects of class \link[admix]{admix_model}, containing useful information about distributions and parameters.
 #' @param conf_level The confidence level of the K-sample test.
-#' @param sim_U (default to NULL) Random draws of the inner convergence part of the contrast as defined in the IBM approach (see 'Details' below).
+#' @param sim_U (default to NULL) Random draws of the inner convergence part of the contrast as defined in the IBM approach (see references below).
 #' @param tune_penalty (default to TRUE) A boolean that allows to choose between a classical penalty term or an optimized penalty (embedding
 #'                     some tuning parameters, automatically optimized). Optimized penalty is particularly useful for low or unbalanced sample sizes
 #'                     to detect alternatives to the null hypothesis (H0). It is recommended to set it to TRUE.
@@ -21,7 +21,7 @@
 #' @references
 #' \insertRef{MilhaudPommeretSalhiVandekerkhove2024b}{admix}
 #'
-#' @return An object of class \link[admix]{admix_test}, containing 17 attributes: 1) the number of samples for the test; 2) the sizes of each sample;
+#' @return An object of class 'IBM_test', containing 17 attributes: 1) the number of samples for the test; 2) the sizes of each sample;
 #'         3) the information about component distributions for each sample; 4) the reject decision of the test; 5) the confidence level
 #'         of the test (1-alpha, where alpha refers to the first-type error); 6) the test p-value; 7) the 95th-percentile of the contrast
 #'         tabulated distribution; 8) the test statistic value; 9) the selected rank (number of terms involved in the test statistic);
@@ -32,7 +32,7 @@
 #'         in case of equal unknown component distributions); 17) the matrix of pairwise contrasts (distance between two samples).
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' ####### Under the null hypothesis H0 (with K=3 populations):
 #' ## Simulate mixture data:
 #' mixt1 <- twoComp_mixt(n = 450, weight = 0.4,
@@ -65,12 +65,16 @@
 #' }
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
-#' @export
+#' @keywords internal
 
 IBM_k_samples_test <- function(samples, admixMod, conf_level = 0.95, sim_U = NULL,
                                tune_penalty = TRUE, n_sim_tab = 100, parallel = FALSE, n_cpu = 2)
 {
+  if (!all(sapply(X = admixMod, FUN = inherits, what = "admix_model")))
+    stop("Argument 'admixMod' is not correctly specified. See ?admix_model.")
+
   old_options_warn <- base::options()$warn
+  on.exit(base::options(warn = old_options_warn))
   base::options(warn = -1)
 
   ## Control whether parallel computations were asked for or not:
@@ -95,8 +99,6 @@ IBM_k_samples_test <- function(samples, admixMod, conf_level = 0.95, sim_U = NUL
       S_ii <- matrix(NA, nrow = length(samples), ncol = 6)
       for (k in 1:length(samples)) {
 
-        #sapply(X = admixMod[as.numeric(model.list[[k]])], "[[", "comp.dist")["known", ]
-        #sapply(X = admixMod[as.numeric(model.list[[k]])], "[[", "comp.param")["known", ]
         ## Artificially create 6 times two subsamples from one given original sample (thus under the null H0):
         subsample1_index <- matrix(NA, nrow = floor(length(samples[[k]])/2), ncol = 6)
         subsample1_index <- replicate(n = 6, expr = sample(x = 1:length(samples[[k]]),
@@ -298,32 +300,38 @@ IBM_k_samples_test <- function(samples, admixMod, conf_level = 0.95, sim_U = NUL
     CDF_U <- stats::ecdf(sim_U)
     p_value <- 1 - CDF_U(finalStat_value)
 
+    names(finalStat_value) <- "Test statistic value"
+    stat_param <- NA ; names(stat_param) <- ""
+    estimated_values <- vector(mode = "numeric", length = 2L)
+    estimated_values <- c(gamma_opt, cst_selected)
+    names(estimated_values) <- c("Tuned Gamma","Tuned constant C")
+
     obj <- list(
+      null.value = unique(q_H),
+      alternative = "greater",
+      method = "Equality test of the unknown distributions (with ICV/IBM)",
+      estimate = estimated_values,
+      data.name = deparse(substitute(samples)),
+      statistic = finalStat_value,
+      parameters = stat_param,
+      p.value = p_value,
       n_populations = length(samples),
       population_sizes = sapply(X = samples, FUN = length),
       admixture_models = admixMod,
       reject_decision = final_test,
       confidence_level = conf_level,
-      p_value = p_value,
-      extreme_quantile_tabul = unique(q_H),
-      test_statistic_value = finalStat_value,
       selected_rank = selected.index,
       statistic_name = finalStat_name,
       penalty_nullHyp = penalty_rule,
       penalized_stat = penalized.stats,
-      tuned_gamma = gamma_opt,
-      tuned_constant = cst_selected,
       tabulated_dist = sim_U,
-      estimated_mixing_weights = NA,
       contrast_matrix = contrast.matrix
     )
-    class(obj) <- c("IBM_test", "admix_test")
-    obj$call <- match.call()
 
-    on.exit(base::options(warn = old_options_warn))
+    class(obj) <- c("IBM_test", "htest")
+    obj$call <- match.call()
     return(obj)
   }
-
 }
 
 #' Print method for objects 'IBM_test'
@@ -332,16 +340,22 @@ IBM_k_samples_test <- function(samples, admixMod, conf_level = 0.95, sim_U = NUL
 #' @param ... A list of additional parameters belonging to the default method.
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
-#' @export
+#' @keywords internal
+#' @noRd
 
 print.IBM_test <- function(x, ...)
 {
   cat("Call:")
   print(x$call)
   cat("\n")
-  cat("Is the null hypothesis (equal unknown distributions) rejected? ",
+  cat("Is the null hypothesis rejected (same distribution for unknown components)? ",
       ifelse(x$reject_decision, "Yes", "No"), sep="")
-  cat("\np-value of the test: ", round(x$p_value,3), "\n", sep="")
+  if (round(x$p.value, 3) == 0) {
+    cat("\np-value of the test: 1e-12", sep="")
+  } else {
+    cat("\np-value of the test: ", round(x$p.value, 3), sep="")
+  }
+  cat("\n")
 }
 
 
@@ -351,7 +365,8 @@ print.IBM_test <- function(x, ...)
 #' @param ... A list of additional parameters belonging to the default method.
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
-#' @export
+#' @keywords internal
+#' @noRd
 
 summary.IBM_test <- function(object, ...)
 {
@@ -373,20 +388,21 @@ summary.IBM_test <- function(object, ...)
     }
   }
   cat("\n----- Test decision -----\n")
-  cat("Is the null hypothesis (equality of unknown distributions) rejected? ",
+  cat("Method: ", object$method, "\n", sep = "")
+  cat("Is the null hypothesis rejected (equality of unknown distributions)? ",
       ifelse(object$reject_decision, "Yes", "No"), sep="")
   cat("\nConfidence level of the test: ", object$confidence_level, sep="")
-  cat("\np-value of the test: ", round(object$p_value,3), sep="")
+  cat("\np-value of the test: ", round(object$p.value,3), sep="")
   cat("\n\n----- Test statistic -----\n")
   cat("Selected rank of the test statistic (following penalization rule): ", object$selected_rank, sep="")
-  cat("\nValue of the test statistic: ", round(object$test_statistic_value,2), "\n", sep="")
+  cat("\nValue of the test statistic: ", round(object$statistic,2), "\n", sep="")
   cat("Discrepancy terms involved in the statistic: ", paste(object$statistic_name, sep = ""), "\n", sep = "")
   cat("Optimal tuning parameters (if argument 'tune.penalty' is true):\n")
-  cat("Gamma: ", object$tuned_gamma, "\n", sep = "")
-  cat("Constant: ", object$tuned_constant, "\n", sep = "")
+  cat("Gamma: ", object$estimate["Tuned Gamma"], "\n", sep = "")
+  cat("Constant: ", object$estimate["Tuned constant C"], "\n", sep = "")
   cat("Chosen penalty rule: ", ifelse(object$penalty_nullHyp, "H0", "H1"), sep = "")
   cat("\n\n----- Tabulated test statistic distribution -----\n")
-  cat("Quantile at level ", object$confidence_level*100, "%: ", round(object$extreme_quantile_tabul, 3), "\n", sep = "")
+  cat("Quantile at level ", object$confidence_level*100, "%: ", round(object$null.value, 3), "\n", sep = "")
   cat("Tabulated distribution: ", paste(utils::head(round(sort(object$tabulated_dist),2),3), collapse = " "), "....",
       paste(utils::tail(round(sort(object$tabulated_dist),2),3), collapse = " "), "\n", sep = "")
   cat("\n")
@@ -440,6 +456,7 @@ summary.IBM_test <- function(object, ...)
 #'                   parallel = FALSE, n_cpu = 2, sim_U = NULL, n_sim_tab = 10)
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
+#' @keywords internal
 #' @noRd
 
 IBM_2samples_test <- function(samples, admixMod, conf_level = 0.95, parallel = FALSE,
@@ -456,7 +473,7 @@ IBM_2samples_test <- function(samples, admixMod, conf_level = 0.95, parallel = F
   }
 
   if (inherits(x = estim, what = "try-error", which = FALSE)) {
-    estim.weights <- 100
+    estim.weights <- c(NA,NA)
     contrast_val <- NA
   } else {
     estim.weights <- estim$estimated_mixing_weights
@@ -482,7 +499,7 @@ IBM_2samples_test <- function(samples, admixMod, conf_level = 0.95, parallel = F
   }
 
   ## Earn computation time using this soft version of the green light criterion:
-  if (any(abs(estim.weights) > 1)) {
+  if ( any(abs(estim.weights) > 1) | any(is.na(estim.weights)) ) {
     reject <- TRUE
     p_value <- 1e-12
     sim_U <- extreme_quantile <- NA
@@ -499,22 +516,39 @@ IBM_2samples_test <- function(samples, admixMod, conf_level = 0.95, parallel = F
     p_value <- 1 - CDF_U(contrast_val)
   }
 
+  names(contrast_val) <- "Test statistic value"
+  stat_param <- NA ; names(stat_param) <- ""
+  if (length(estim.weights) > 1) {
+    estimated_values <- estim.weights
+  } else {
+    estimated_values <- c(0.2,estim.weights)
+  }
+  names(estimated_values) <- c("Weight in 1st sample","Weight in 2nd sample")
+
   obj <- list(
+    null.value = unique(extreme_quantile),
+    alternative = "greater",
+    method = "Equality test of the unknown distributions (with ICV/IBM)",
+    estimate = estimated_values,
+    data.name = deparse(substitute(samples)),
+    statistic = contrast_val,
+    parameters = stat_param,
+    p.value = p_value,
+    n_populations = 2,
+    population_sizes = sapply(X = samples, FUN = length),
+    admixture_models = admixMod,
     reject_decision = reject,
     confidence_level = conf_level,
-    p_value = p_value,
-    extreme_quantile_tabul = extreme_quantile,
-    test_statistic_value = contrast_val,
     selected_rank = NA,
     statistic_name = NA,
     penalty_nullHyp = NA,
     penalized_stat = NA,
-    tuned_gamma = NA,
-    tuned_constant = NA,
     tabulated_dist = sim_U,
-    estimated_mixing_weights = estim.weights,
     contrast_matrix = NA
   )
+
+  class(obj) <- c("IBM_test", "htest")
+  obj$call <- match.call()
   return(obj)
 }
 
@@ -565,6 +599,7 @@ IBM_2samples_test <- function(samples, admixMod, conf_level = 0.95, parallel = F
 #' }
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
+#' @keywords internal
 #' @noRd
 
 IBM_greenLight_criterion <- function(estim_obj, samples, admixMod, alpha = 0.05)
@@ -627,7 +662,7 @@ IBM_greenLight_criterion <- function(estim_obj, samples, admixMod, alpha = 0.05)
 #'         4) support that was used to evaluate the variance-covariance matrix of the empirical processes.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' ## Simulate mixture data:
 #' mixt1 <- twoComp_mixt(n = 1200, weight = 0.4,
 #'                       comp.dist = list("norm", "norm"),
@@ -649,7 +684,8 @@ IBM_greenLight_criterion <- function(estim_obj, samples, admixMod, alpha = 0.05)
 #' }
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
-#' @export
+#' @keywords internal
+#' @noRd
 
 IBM_tabul_stochasticInteg <- function(samples, admixMod, min_size = NULL, n.varCovMat = 80,
                                       n_sim_tab = 100, parallel = FALSE, n_cpu = 2)
