@@ -1,19 +1,19 @@
-#' Estimates the decontaminated density of the unknown component in an admixture
+#' Probability density function of the unknown component
 #'
 #' Estimate the decontaminated density of the unknown component in the admixture model under study, after inversion of the admixture
 #' cumulative distribution function. Recall that an admixture model follows the cumulative distribution function (CDF) L, where
 #' L = p*F + (1-p)*G, with g a known CDF and p and f unknown quantities.
 #'
 #' @param sample1 Sample under study.
-#' @param estim.p The estimated weight of the unknown component distribution, related to the proportion of the unknown component
-#'                in the admixture model studied.
-#' @param admixMod An object of class 'admix_model', containing useful information about distributions and parameters.
+#' @param estim.p The estimated weight, related to the proportion of the unknown component distribution in the admixture model studied.
+#' @param admixMod An object of class 'admix_model', containing useful information about known distribution(s) and parameter(s).
 #'
 #' @details The decontaminated density is obtained by inverting the admixture density, given by l = p*f + (1-p)*g, to isolate the
 #'          unknown component f after having estimated p.
 #'
-#' @return An object of class 'decontaminated_density', containing 2 attributes: 1) the decontaminated density function;
-#'         2) the type of support for the underlying distribution (either discrete or continuous, useful for plots).
+#' @return An object of class 'decontaminated_density', containing 3 attributes: 1) the data under study;
+#'         2) the type of support for the underlying distribution (either discrete or continuous, useful for plots);
+#'         3) the decontaminated density function.
 #'
 #' @examples
 #' ## Simulate mixture data:
@@ -83,6 +83,9 @@
 
 decontaminated_density <- function(sample1, estim.p, admixMod)
 {
+  if (!inherits(x = admixMod, what = "admix_model"))
+    stop("Argument 'admixMod' is not correctly specified. See ?admix_model.")
+
   ## Extract the information on component distributions:
   knownComp.dens <- paste0("d", admixMod$comp.dist$known)
   if (any(knownComp.dens == "dmultinom")) { knownComp.dens[which(knownComp.dens == "dmultinom")] <- "approxfun" }
@@ -119,8 +122,9 @@ decontaminated_density <- function(sample1, estim.p, admixMod)
   }
   f1_decontamin <- function(x) (1/estim.p) * (l1_emp(x) - (1-estim.p) * g1(x))
 
-  obj <- list(decontaminated_density_fun = f1_decontamin,
-              support = support)
+  obj <- list(data = sample1,
+              support = support,
+              decontaminated_density_fun = f1_decontamin)
   class(obj) <- "decontaminated_density"
   obj$call <- match.call()
 
@@ -135,7 +139,7 @@ decontaminated_density <- function(sample1, estim.p, admixMod)
 #' @param x An object of class 'decontaminated_density' (see ?decontaminated_density).
 #' @param ... Arguments to be passed to generic method 'plot', such as graphical parameters (see par).
 #'
-#' @return More important information about the decontaminated density.
+#' @return The function related to the estimated decontaminated density.
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
 #' @export
@@ -147,12 +151,35 @@ print.decontaminated_density <- function(x, ...)
   cat("\n")
   print(x$decontaminated_density_fun)
   cat("\n")
-  cat("Type of support: ", x$support, sep = "")
 }
 
 
+#' Summary method for object of class 'decontaminated_density'
+#'
+#' Summarizes information about the estimated decontaminated density function.
+#'
+#' @param object An object of class 'decontaminated_density' (see ?decontaminated_density).
+#' @param ... Arguments to be passed to generic method 'summary'.
+#'
+#' @return Classical statistical indicators about the decontaminated density.
+#'
+#' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
+#' @export
 
-#' Plot method for class 'decontaminated_density'
+summary.decontaminated_density <- function(object, ...)
+{
+  cat("Call:")
+  print(object$call)
+  cat("\n")
+  cat("Type of support: ", object$support, sep = "")
+  cat("\n\n")
+  cat("Statistics about the estimated decontaminated density function:\n")
+  print(summary(object$decontaminated_density_fun(object$data)))
+  cat("\n")
+}
+
+
+#' Plot method for object of class 'decontaminated_density'
 #'
 #' Plot the decontaminated density of the unknown component from some admixture model, after inversion of the admixture
 #' cumulative distribution functions.
@@ -161,7 +188,7 @@ print.decontaminated_density <- function(x, ...)
 #' @param x_val (numeric) A vector of points at which to evaluate the probability mass/density function.
 #' @param add_plot (default to FALSE) A boolean specifying if one plots the decontaminated density over an existing plot. Used for visual
 #'                 comparison purpose.
-#' @param ... Arguments to be passed to generic method 'plot', such as graphical parameters (see par).
+#' @param ... Arguments to be passed to generic method 'plot', such as graphical parameters (see ?par).
 #'
 #' @details The decontaminated density is obtained by inverting the admixture density, given by l = p*f + (1-p)*g, to isolate the
 #'          unknown component f after having estimated p and l.
@@ -276,6 +303,7 @@ plot.decontaminated_density <- function(x, x_val, add_plot = FALSE, ...)
     }
   } else {
     old_par_new <- graphics::par()$new
+    on.exit(graphics::par(new = old_par_new))
     graphics::par(new = TRUE)
     if (support == "Discrete") {
       graphics::barplot(height = decontamin_dens_values, names = as.character(x_val), add = add_plot,
@@ -283,7 +311,6 @@ plot.decontaminated_density <- function(x, x_val, add_plot = FALSE, ...)
     } else {
       graphics::lines(x = x_val, y = decontamin_dens_values, ...)
     }
-    on.exit(graphics::par(new = old_par_new))
   }
 }
 
@@ -335,9 +362,13 @@ plot.decontaminated_density <- function(x, x_val, add_plot = FALSE, ...)
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
 #' @export
+#' @keywords internal
 
 decontaminated_cdf <- function(sample1, estim.p, admixMod)
 {
+  if (!inherits(x = admixMod, what = "admix_model"))
+    stop("Argument 'admixMod' is not correctly specified. See ?admix_model.")
+
   ## Extract the information on component distributions:
   knownComp.CDF <- paste0("p", admixMod$comp.dist$known)
   if (any(knownComp.CDF == "pmultinom")) { knownComp.CDF[which(knownComp.CDF == "pmultinom")] <- "stepfun" }
