@@ -23,7 +23,11 @@
 #'         density); 7) the variance of the two estimators (respectively the mixing proportion and location shift); 8) the optimization
 #'         method that was used.
 #'
+#' @seealso [print.estim_BVdk()] for printing a short version of the results from this estimation method,
+#'          and [summary.estim_BVdk()] for more comprehensive results.
+#'
 #' @examples
+#' \dontrun{
 #' ## Simulate mixture data:
 #' mixt1 <- twoComp_mixt(n = 200, weight = 0.4,
 #'                       comp.dist = list("norm", "norm"),
@@ -48,12 +52,16 @@
 #' ## Perform the estimation of parameters in real-life:
 #' estim_BVdk(samples = data2, admixMod = admixMod2, method = 'L-BFGS-B',
 #'            compute_var = TRUE)
+#' }
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
-#' @export
+#' @keywords internal
 
 estim_BVdk <- function(samples, admixMod, method = c("L-BFGS-B","Nelder-Mead"), compute_var = FALSE)
 {
+  if (!inherits(x = admixMod, what = "admix_model"))
+    stop("Argument 'admixMod' is not correctly specified. See ?admix_model.")
+
   warning("Estimation by 'BVdk' assumes the unknown component distribution
   to have a symmetric probability density function.\n")
   ## Extract useful information about known component distribution:
@@ -116,17 +124,18 @@ estim_BVdk <- function(samples, admixMod, method = c("L-BFGS-B","Nelder-Mead"),
 #' @param ... A list of additional parameters belonging to the default method.
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
-#' @export
+#' @keywords internal
 
 print.estim_BVdk <- function(x, ...)
 {
-  cat("\nCall:")
-  print(x$call)
+#  cat("\nCall:")
+#  print(x$call)
+  cat("\n")
+  cat("Estimated mixing weight:", round(x$estimated_mixing_weights,3),
+      "/ Estimated location shift:", round(x$estimated_locations,3),"\n")
+  cat("Variance of weight estimator:", round(x$mix_weight_variance,5),
+      "/ Variance of loc. estimator:", round(x$location_variance,5), "\n")
   cat("\n")
-  cat("Estimated mixing proportion: ", x$estimated_mixing_weights, "\n")
-  cat("Estimated location parameter: ", x$estimated_locations, "\n")
-  cat("Variance of the mixing proportion estimator: ", x$mix_weight_variance, "\n")
-  cat("Variance of the location shift estimator: ", x$location_variance, "\n\n")
 }
 
 
@@ -138,7 +147,7 @@ print.estim_BVdk <- function(x, ...)
 #' @param ... A list of additional parameters belonging to the default method.
 #'
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
-#' @export
+#' @keywords internal
 
 summary.estim_BVdk <- function(object, ...)
 {
@@ -147,16 +156,17 @@ summary.estim_BVdk <- function(object, ...)
   cat("\n")
   cat("------- Sample -------\n")
   cat("Sample size: ", object$population_sizes, "\n")
-  cat("-> Distribution and parameters of the known component \n in the admixture model: ", sep="")
-  cat(object$admixture_models$comp.dist$known, "\n")
-  print(unlist(object$admixture_models$comp.param$known, use.names = TRUE))
+  cat("-> Distribution of the known component:", object$admixture_models$comp.dist$known, "\n", sep="")
+  cat("-> Parameter(s) of the known component:", paste(names(object$admixture_models$comp.param$known), object$admixture_models$comp.param$known, collapse="\t", sep="="), sep="")
+  cat("\n")
   cat("\n------- Estimation results -------\n")
-  cat("Estimated mixing proportion: ", object$estimated_mixing_weights, "\n")
-  cat("Estimated location parameter: ", object$estimated_locations, "\n")
-  cat("Variance of the mixing proportion estimator: ", object$mix_weight_variance, "\n")
-  cat("Variance of the location shift estimator: ", object$location_variance, "\n\n")
+  cat("Estimated mixing proportion:", object$estimated_mixing_weights, "\n")
+  cat("Estimated location shift parameter:", object$estimated_locations, "\n")
+  cat("Variance of the mixing proportion estimator:", object$mix_weight_variance, "\n")
+  cat("Variance of the location estimator:", object$location_variance, "\n\n")
   cat("------- Optimization -------\n")
-  cat("Optimization method: ", object$optim_method, "\n\n")
+  cat("Optimization method: ", object$optim_method)
+  cat("\n")
 }
 
 
